==> authx-0.3.1.tar.gz: authx-0.3.1/docs/help.md <==
# Help AuthX - Get Help 🦥

Do you like **AuthX**?

Would you like to help AuthX, other users, and the author?

Or would you like to get help with **AuthX**?

There are very simple ways to help (several involve just one or two clicks).

And there are several ways to get help too.

## Follow AuthX's Author

<a href="https://twitter.com/THyasser1" class="external-link" target="_blank">Follow @THyasser1 on **Twitter**</a> to get the latest news about **AuthX**.

## Star **AuthX** in GitHub

You can "star" AuthX in GitHub (clicking the star button at the top right): <a href="https://github.com/yezz123/AuthX" class="external-link" target="_blank">https://github.com/yezz123/AuthX</a>. ⭐️

By adding a star, other users will be able to find it more easily and see that it has been already useful for others.

## Watch the GitHub repository for releases

You can "watch" AuthX in GitHub (clicking the "watch" button at the top right): <a href="https://github.com/yezz123/AuthX" class="external-link" target="_blank">https://github.com/yezz123/AuthX</a>. 👀

There you can select __"Releases only"__.

By doing it, you will receive notifications (in your email) whenever there's a new release (a new version) of **AuthX** with bug fixes and new features.

## Help Author with issues in GitHub

You can see <a href="https://github.com/yezz123/AuthX/issues" class="external-link" target="_blank">existing issues</a> and try and help others, most of the times they are questions that you might already know the answer for. 🤓

## Watch the GitHub repository

You can "watch" AuthX in GitHub (clicking the "watch" button at the top right): <a href="https://github.com/yezz123/AuthX" class="external-link" target="_blank">https://github.com/yezz123/AuthX</a>. 👀

If you select "Watching" instead of "Releases only" you will receive notifications when someone creates a new issue.

Then you can try and help them solve those issues.

## Create issues

You can <a href="https://github.com/yezz123/AuthX/issues/new/choose" class="external-link" target="_blank">create a new issue</a> in the GitHub repository, for example to:

* Ask a **question** or ask about a **problem**.
* Suggest a new **feature**.

**Note**: if you create an issue, then I'm going to ask you to also help others. 😉

## Create a Pull Request

You can [contribute](contributing.md) to the source code with Pull Requests, for example:

* To fix a typo you found on the documentation.
* To help [translate the documentation](contributing.md) to your language.
    * You can also help to review the translations created by others.
* To propose new documentation sections.
* To fix an existing issue/bug.
* To add a new feature.

## Sponsor the author

You can also financially support the author (me) through <a href="https://paypal.me/yassertahiri?locale.x=en_US" class="external-link" target="_blank">Paypal sponsors</a>.

There you could buy me a [coffee ☕️](https://www.buymeacoffee.com/tahiri) to say thanks. 😄

And you can also become a Silver or Gold sponsor for AuthX. 🏅🎉

## Sponsor the tools that power AuthX

As you have seen in the documentation, AuthX stands on the shoulders of giants, FastAPI, Starlette and Pydantic.

You can also sponsor:

* <a href="https://github.com/sponsors/tiangolo" class="external-link" target="_blank">Sebastián Ramírez (FastAPI)</a>
* <a href="https://github.com/sponsors/samuelcolvin" class="external-link" target="_blank">Samuel Colvin (Pydantic)</a>
* <a href="https://github.com/sponsors/encode" class="external-link" target="_blank">Encode (Starlette, Uvicorn)</a>

---

Thanks! 🚀

==> authx-0.5.0.tar.gz: authx-0.5.0/docs/help.md <==
# Help AuthX - Get Help 🦥

Do you like **AuthX**?

Would you like to help AuthX, other users, and the author?

Or would you like to get help with **AuthX**?

There are very simple ways to help (several involve just one or two clicks).

And there are several ways to get help too.

## Follow AuthX's Author

<a href="https://twitter.com/THyasser1" class="external-link" target="_blank">Follow @THyasser1 on **Twitter**</a> to get the latest news about **AuthX**.

## Star **AuthX** in GitHub

You can "star" AuthX in GitHub (clicking the star button at the top right): <a href="https://github.com/yezz123/AuthX" class="external-link" target="_blank">https://github.com/yezz123/AuthX</a>. ⭐️

By adding a star, other users will be able to find it more easily and see that it has been already useful for others.

## Watch the GitHub repository for releases

You can "watch" AuthX in GitHub (clicking the "watch" button at the top right): <a href="https://github.com/yezz123/AuthX class="external-link" target="_blank">https://github.com/yezz123/AuthX</a>. 👀

There you can select **"Releases only"**.

By doing it, you will receive notifications (in your email) whenever there's a new release (a new version) of **AuthX** with bug fixes and new features.

## Help Author with issues in GitHub

You can see <a href="https://github.com/yezz123/AuthX/issues" class="external-link" target="_blank">existing issues</a> and try and help others, most of the times they are questions that you might already know the answer for. 🤓

## Watch the GitHub repository

You can "watch" AuthX in GitHub (clicking the "watch" button at the top right): <a href="https://github.com/yezz123/AuthX class="external-link" target="_blank">https://github.com/yezz123/AuthX</a>. 👀

If you select "Watching" instead of "Releases only" you will receive notifications when someone creates a new issue.

Then you can try and help them solve those issues.

## Create issues

You can <a href="https://github.com/yezz123/AuthX/issues/new/choose" class="external-link" target="_blank">create a new issue</a> in the GitHub repository, for example to:

* Ask a **question** or ask about a **problem**.
* Suggest a new **feature**.

**Note**: if you create an issue, then I'm going to ask you to also help others. 😉

## Create a Pull Request

You can [contribute](contributing.md) to the source code with Pull Requests, for example:

* To fix a typo you found on the documentation.
* To help [translate the documentation](contributing.md) to your language.
  * You can also help to review the translations created by others.
* To propose new documentation sections.
* To fix an existing issue/bug.
* To add a new feature.

## Sponsor the author

You can also financially support the author (me) through <a href="https://paypal.me/yassertahiri?locale.x=en_US" class="external-link" target="_blank">Paypal sponsors</a>.

There you could buy me a [coffee ☕️](https://www.buymeacoffee.com/tahiri) to say thanks. 😄

And you can also become a Silver or Gold sponsor for AuthX. 🏅🎉

<a href="https://www.producthunt.com/posts/authx?utm_source=badge-featured&utm_medium=badge&utm_souce=badge-authx" target="_blank"><img src="https://api.producthunt.com/widgets/embed-image/v1/featured.svg?post_id=318189&theme=light" alt="AuthX - A FastAPI package for Auth made by a human not an AI | Product Hunt" style="width: 250px; height: 54px;" width="250" height="54" /></a>
<a href="https://www.buymeacoffee.com/tahiri" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" ></a>

## Sponsor the tools that power AuthX

As you have seen in the documentation, AuthX stands on the shoulders of giants, FastAPI, Starlette and Pydantic.

You can also sponsor:

* <a href="https://github.com/sponsors/tiangolo" class="external-link" target="_blank">Sebastián Ramírez (FastAPI)</a>
* <a href="https://github.com/sponsors/samuelcolvin" class="external-link" target="_blank">Samuel Colvin (Pydantic)</a>
* <a href="https://github.com/sponsors/encode" class="external-link" target="_blank">Encode (Starlette, Uvicorn)</a>

---

Thanks! 🚀
